import os
from setuptools import find_packages, setup

with open('requirements.txt') as f:
    required = f.read().splitlines()


def package_files(directory):
    paths = []
    for (path, directories, filenames) in os.walk(directory):
        for filename in filenames:
            paths.append(os.path.join('..', path, filename))
    return paths


def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()


dsp_files = package_files('dsframework/cli/tester/dsp')
extra_files = package_files('dsframework/cli/tester/deploy_files')
cloud_eval_extra_files = package_files('dsframework/cli/tester/cloud_eval')
batch_extra_files = package_files('dsframework/cli/tester/batch_files')
documentation_files = package_files('dsframework/documentation')

setup(
    name='dsFramework',
    py_modules=['api_cli'],

    packages=find_packages(include=['dsframework*']),
    package_data={'': ['config.json', 'cors_allowed_origins.json', '.gitignore'] +
                      extra_files + cloud_eval_extra_files + dsp_files + documentation_files + batch_extra_files},
    entry_points='''
        [console_scripts]
        dsf-cli=api_cli:cli
    ''',
    version='0.1.85',
    description='Data science framework library',
    long_description=read('README.md'),
    long_description_content_type='text/markdown',
    # url='http://pypi.python.org/pypi/PackageName/',
    author='oribrau@gmail.com',
    license='MIT',
    install_requires=required,
    setup_requires=['pytest-runner'],
    tests_require=['pytest'],
    test_suite='tests',
)

# Commands
# for test -  python setup.py pytest
# for build wheel -  python setup.py bdist_wheel
# for source dist -  python setup.py sdist
# for build -  python setup.py build
# for install -  python setup.py install
# for uninstall - python -m pip uninstall dsframework
# for install - python -m pip install dist/dsframework-0.1.0-py3-none-any.whl
# for installing from the local work dir - pip install <path to local directory>

# Deploy to PyPI
# delete dist and build folders
# python setup.py bdist_wheel
# python setup.py sdist
# python setup.py build
# twine upload dist/*
'''
    use
    1. python setup.py install
    2. dsf-cli g model new_model_name
    3. twine check dist/*
    4. twine upload --repository-url https://pypi.org/legacy/ dist/*
    4. twine upload dist/*
    
    pip install dsframework --index-url https://pypi.org/simple
    
    how to use
    
    pip install dsframework
    
    dsf-cli generate project my-new-model
'''



import requests
import json
import sys
from server.token_generator import tokenGenerator

env = sys.argv[1]
model = json.loads(sys.argv[2])
dataset = json.loads(sys.argv[3])
tag_name = sys.argv[4]

t = tokenGenerator()
jwtToken = t.generateToken(env.upper() + '_Conf')

data={
  "model_type_id": model['id'],
  "model_name": model['name'],
  "repo_tag": tag_name,
  "repo": model['repo'],
  "dataset_id": dataset['id'],
  "dataset_name": dataset['dataset_name'],
  "created_by": "ori.braun@zoominfo.com"
}
print('data', data)
url="https://dsp.zoominfo.com/api/v1/experiment/add"
if env == 'stg':
	url = "https://dsp-stg.zoominfo.com/api/v1/experiment/add"
headers = {
    'x-token': 'fake-super-secret-token',
    'Authorization': 'Bearer ' + jwtToken
}

response = requests.post(url, json=data, headers=headers)
try:
	result = json.loads(response.content)
	print(result)
except Exception as e:
	print('error', e)



"""! @brief Pipeline class, implements ZIDS_Pipeline base class."""
import os

__location__ = os.path.realpath(
    os.path.join(os.getcwd(), os.path.dirname(__file__)))

from dsframework.base.pipeline.pipeline import ZIDS_Pipeline

from .preprocessor.preprocess import generatedProjectNamePreprocess
from .postprocessor.postprocess import generatedProjectNamePostprocess
from .predictors.predictor import generatedProjectNamePredictor
from .forcers.forcer import generatedProjectNameForcer
from .artifacts.shared_artifacts import generatedProjectNameSharedArtifacts

##
# @file
# @brief Pipeline main class, implements ZIDS_Pipeline base class.
class generatedClass(ZIDS_Pipeline):
    """! Pipeline main class

    Its main job is to build the pipeline components, by default it includes four main components:
    preprocess, predictor, forcer and postprocess.
    """

    def __init__(self):
        """! The generatedClass class (Pipeline) initializer."""

        ##
        # @hidecallgraph @hidecallergraph
        super().__init__()

    def get_artifacts(self):
        """! Loads the artifacts and return the results.

        Triggers execution of load_artifacts and load_vocabs on base class ZIDS_SharedArtifacts.
        It overrides ZIDS_Pipeline.get_artifacts.


        Returns:
             generatedProjectNameSharedArtifacts() - Results of loaded artifacts.

        """
        return generatedProjectNameSharedArtifacts()

    def build_pipeline(self):
        """! Builds the pipeline.

        Instantiate the default four main components:
        Preprocessor, Predictor, Forcer and Postprocessor.
        """

        ##
        # Additional components can be added using the add_component method, for example:
        # @code
        # self.new_component = generatedProjectNameNewComponent()
        # self.add_component(self.new_component)
        # @endcode

        ## Instantiate preprocessor - Automatically added to the pipeline
        self.preprocessor = generatedProjectNamePreprocess(artifacts=self.artifacts)

        ## Instantiate and add predictor to the pipeline
        self.predictor = generatedProjectNamePredictor()
        self.add_component(self.predictor)

        ## Instantiate and add forcer to the pipeline
        self.forcer = generatedProjectNameForcer()
        self.add_component(self.forcer)

        ## Instantiate postprocessor - Automatically added to the pipeline
        self.postprocessor = generatedProjectNamePostprocess(artifacts=self.artifacts)

    def preprocess(self, **kwargs):
        """! Executes preprocessor, called from ZIDS_Pipeline baseclass execute method.

        Args:
            **kwargs : Dataset and additional parameters loaded initially.
        Returns:
            List of predictable objects (generatedProjectNameInputs datatype)
        """
        return self.preprocessor(**kwargs)

    def postprocess(self, predictables):
        """! Executes the postprocessor, called from ZIDS_Pipeline baseclass execute method.

        Args:
            predictables: List[generatedProjectNameInputs] - List of predictable objects.
        Returns:
            generatedProjectNamePostprocess: List[generatedProjectNameOutputs]: List of results.
        """
        return self.postprocessor(predictables)



import os
import sys


def read_file(file_path):
    with open(file_path, 'r') as file:
        data = file.read()
        return data


def modify_files(files_list, change_source, change_dest, url_name):
    """! Replaces a string in a list of files.

        Args:
            files_list: List of files to run search on.
            change_source: Source text to search.
            change_dest: Text to be inserted.
            url_name: Url to be used in inserted text.

    """
    for file in files_list:
        data = read_file(file[0])
        new_url = url_name if file[1] == '.' else url_name + file[1] + '/'
        change_dest1 = change_dest.replace('url_tag', new_url)
        data = data.replace(change_source, change_dest1)

        if os.path.exists(file[0]):
            os.remove(file[0])

        save_file(file[0], data)


def find_files(path, ext):
    """! Find files in path with specified extension.

    Args:
        path: File path
        ext: Required file extension

    Returns:
        List with files abs paths and sub folder name.
    """

    files_path = []

    for root, dirs, files in os.walk(path):
        file_list = [[os.path.join(root, file), os.path.relpath(root, path)] for file in files if file.endswith(ext)]
        files_path.extend(file_list)

    return files_path


def save_file(file_name_path, data):
    f = open(file_name_path, "w")
    f.write(data)
    f.close()


if __name__ == '__main__':
    current_doc_folder = sys.argv[1]
    base_tag_path = sys.argv[2]

    print("Finding files...")
    html_list = find_files(current_doc_folder, 'html')
    css_list = find_files(current_doc_folder, 'css')

    print(f'Found {len(html_list)} html files.')
    print(f'Found {len(css_list)} css files.')

    print("Modifying files...")
    modify_files(html_list, '<head>', '<head><base href=\"url_tag\">', base_tag_path)
    modify_files(css_list, "url(\'", "url(\'url_tag", base_tag_path)
    modify_files(css_list, "url(\"", "url(\"url_tag", base_tag_path)

    print("Adding <base> tag done!")



"""! @brief ZIDS_Dag base class for the batch dag class.
The DAG (Directed acyclic graph) will trigger the workflow, derived from the workflow template"""

from json import load as json_load
import sys
from typing import List, Any
import os


##
# @file
# @brief Defines dag base class.
class ZIDS_Dag():
    def __init__(self):
        """! ZIDS_Dag initializer.
        Loads config file.
        """

        file_path = sys.modules[self.__class__.__module__].__file__
        curr_path = file_path[:file_path.rfind("batch_files")]

        dag_config = None
        with open(curr_path + '/batch_files/batch_config.json') as batch_cfg_file:
            dag_config = json_load(batch_cfg_file)

        self.environment = dag_config['environment']
        self.bucket_name = dag_config['bucket_name']
        self.project_id = dag_config['project_id']
        self.project_name = dag_config['project_name']
        self.orig_project_name = self.project_name
        self.template_id = dag_config['template_id']
        self.region = dag_config['region']
        self.unique_template_id = dag_config['unique_template_id']
        self.unique_iteration_id = dag_config['unique_iteration_id']

        # For Stg and Prd environments, we want DAG to be created and immediately be active
        self.start_as_paused = False

        env_type = os.environ.get('SPRING_PROFILES_ACTIVE')
        if (not env_type == 'production') and (not env_type == 'staging'):
            self.start_as_paused = True

    def get_basic_dag_code(self) -> str:
        """! Get basic code for dag creation
        Returns:
            A string, containing tailored code for creation of a DAG
        """
        dag_str = '''
        # STEP 1: Libraries needed
        from datetime import timedelta, datetime
        from airflow import models
        from airflow.providers.google.cloud.operators.dataproc import DataprocInstantiateWorkflowTemplateOperator

        region = "''' + self.region + '''"
        zone = region + '-b'
        project_id = "''' + self.project_id + '''"
        template_id = "''' + self.template_id + '''"
        bucket_name = "''' + self.bucket_name + '''"
        project_name = "''' + self.project_name + '''"
        orig_project_name = project_name
        unique_iteration_id = "''' + self.unique_iteration_id + '''"
        unique_template_id = "''' + self.unique_template_id + '''"
        if unique_template_id:
            template_id = template_id + '_' + unique_template_id
            orig_project_name = orig_project_name + '_' + unique_template_id
        if unique_iteration_id:
            project_name = project_name + '/unique_iteration_id_' + unique_iteration_id
        else:
            project_name = project_name + '/main'

        dags_bucket_path = f'gs://{bucket_name}/dags'

        now = datetime.now().replace(hour=0, minute=0, second=0, microsecond=0)
        now = now - timedelta(days=1)
        # STEP 3: Set default arguments for the DAG
        default_dag_args = {
            'start_date': now,
            'depends_on_past': False,
            'email_on_failure': False,
            'email_on_retry': False,
            'retries': 1,
            'retry_delay': timedelta(minutes=5)
        }
        # Define a DAG (directed acyclic graph) of tasks.
        # Any task you create within the context manager is automatically added to the
        # DAG object.
        with models.DAG(
            orig_project_name + '_workflow_dag',
            description='DAG for deployment a Dataproc Cluster for ' + project_id,
            # schedule_interval=timedelta(days=1),
            schedule_interval='@daily',
            default_args=default_dag_args,
            is_paused_upon_creation=''' + str(self.start_as_paused) + '''
        ) as dag:

            start_template_job = DataprocInstantiateWorkflowTemplateOperator(
                # The task id of your job
                task_id="dataproc_workflow_dag_python",
                # The template id of your workflow
                template_id=template_id,
                project_id=project_id,
                # The region for the template
                region=region,
                parameters={"START_DATE": "{{ execution_date }}","END_DATE": "{{ next_execution_date }}"}
            )

        '''
        return dag_str

    def create_dag(self):
        """! ZIDS_Dag main function.
        This function is the "entrypoint" for the dag creation.
        """

        raise NotImplementedError




import os
from typing import List
from google.cloud.dataproc_v1.types.workflow_templates import WorkflowTemplate, TemplateParameter
from google.cloud.dataproc_v1.types import OrderedJob, PySparkJob
from dsframework.base.batch.workflow_base import ZIDS_Workflow


class Workflow(ZIDS_Workflow):

    def __init__(self):
        """! Loads config file and initializes parameters.
        """
        self.default_jars = ['gs://spark-lib/bigquery/spark-bigquery-latest_2.12.jar']
        main_project_path = os.path.abspath(os.path.join(os.path.dirname(__file__), "../.."))

        self.pip_packages = ''
        with open(main_project_path + '/requirements_docker.txt') as req_file:
            required_pkg = req_file.read().splitlines()
            required_pkg = [x for x in required_pkg if "#" not in x]
            self.pip_packages = ' '.join(required_pkg)

        super().__init__(self.pip_packages)

    def create_job(self, stage_name, prerequisite_list=None) -> OrderedJob():
        """! create a job from a given stage

            ARGS:
                stage_name: Name of the stage to create
                prerequisite_list: list of stage id's that are mandatory to run before current stage

            Returns:
                An Ordered Job, to be inserted into the workflow template
        """
        stage_dir = f'batch_files/stages/{stage_name}'

        stage_job = self.create_ordered_job(stage_dir)

        if prerequisite_list is not None:
            stage_job.prerequisite_step_ids = prerequisite_list

        return stage_job

    def create_stages(self) -> List[OrderedJob]:
        """! create the stages for the workflow stages
            Returns:
                A List of Ordered Jobs, to be inserted into the workflow template
        """
        # stage get_data
        stage_get_data_job = self.create_job("get_data")

        # stage run_pipeline
        prerequisite_list = [self.project_name + '-stage_get_data']
        stage_run_pipeline_job = self.create_job("run_pipeline", prerequisite_list)

        # stage set_data
        prerequisite_list = [self.project_name + '-stage_run_pipeline']
        stage_set_data_job = self.create_job("set_data", prerequisite_list)

        return [stage_get_data_job, stage_run_pipeline_job, stage_set_data_job]

    def finalize_jobs(self, workflow_template):
        """! create the stages for the workflow stages
            ARGS:
                workflow_template: Workflow templates. Includes jobs that we wish to modify
        """

        # Set start and end dates from Airflow composer
        workflow_template.parameters = []
        for job in workflow_template.jobs:
            start_date_param = TemplateParameter()
            start_date_param.description = "start date from airflow composer"
            start_date_param.name = "START_DATE"
            start_date_param.fields = [
                "jobs['" + job.step_id + "'].pysparkJob.args[1]"
            ]
            end_date_param = TemplateParameter()
            end_date_param.description = "end date from airflow composer"
            end_date_param.name = "END_DATE"
            end_date_param.fields = [
                "jobs['" + job.step_id + "'].pysparkJob.args[2]"
            ]
            workflow_template.parameters.append(start_date_param)
            workflow_template.parameters.append(end_date_param)

        # Make sure to change jobs according to specific configuration
        if self.config['specific_jobs_to_run'] and len(self.config['specific_jobs_to_run']):
            specific_jobs_to_run = []
            for job in workflow_template.jobs:
                if job.step_id in self.config['specific_jobs_to_run']:
                    specific_jobs_to_run.append(job)
                    if len(job.prerequisite_step_ids) and not all(
                            elem in specific_jobs_to_run for elem in job.prerequisite_step_ids):
                        raise Exception("job depends on another job not in specific_jobs_to_run list")
            workflow_template.jobs = specific_jobs_to_run

    def create_workflow_template(self):
        """! Create the workflow template, along with all relevant stages
        """
        service_client = None
        template = None

        # Make sure that a cluster exists
        self.check_cluster()

        # Define template structure
        service_client, template = self.create_template_structure()
        template.jobs = self.create_stages()
        self.finalize_jobs(template)
        # print(template)
        # print(f"project_path: {self.project_path}")

        # Make sure that the template does not exist
        self.check_template(service_client, template)

        # Create template
        self.create_template(service_client, template)

        # When working on "dev" mode, instantiate the template with this function
        self.instantiate_template(service_client, template)


if __name__ == "__main__":
    """! Triggers the creation of the workflow template, starting from
    basic configuration, defining and creating jobs from the existing stages, 
    and up to creating and instantiating the workflow, if needed.
    """

    workflow = Workflow()
    workflow.create_workflow_template()



#!/usr/bin/env python
# coding: utf-8

##
# @file
# @brief ZIDS_Component base class for all pipeline components.

from typing import List, Any


class ZIDS_Component:
    """! ZIDS_Component is the base class for the pipeline components:

    ZIDS_Preprocessor, Predictor, Forcer and ZIDS_Postprocessor.

    It declares phases based on UVM (Universal Verification Methodology) and by this gives us a structured
    way to work in each one of the main components by overriding and implementing those phases.


    **Important note:**

    Those methods are divided into **two groups**, the ones that run from the **@ref __init__()** and those
    that run from the **execute()** method, use them based on the required execution order.
    """

    def __init__(self, artifacts=None) -> None:
        """ZIDS_Component class initializer, runs during __init__.

        It runs the following UVM based phases:
        - build
        - config
        - config_from_json
        - connect
        """

        ## Shared artifacts instance.
        self.artifacts = artifacts
        self.build()
        self.config()
        self.config_from_json()
        self.connect()

    def __call__(self, predictables: List[Any], **kwargs):
        """Runs the execute method."""
        return self.execute(predictables, **kwargs)

    def execute(self, predictables: List[Any], **kwargs) -> List[Any]:
        """Executes additional UVM phases.

        Includes:
        - reset
        - pre_run
        - run
        - post_run
        - evaluate
        """
        self.reset(predictables)
        self.pre_run(predictables)
        self.run(predictables)
        self.post_run(predictables)
        self.evaluate(predictables)
        return predictables

    def build(self):
        """Called from __init__,  not implemented, override to implement."""
        pass

    def config(self):
        """Called from __init__,  not implemented, override to implement."""
        pass

    def config_from_json(self):
        """Called from __init__,  not implemented, override to implement."""
        pass

    def connect(self):
        """Called from __init__,  not implemented, override to implement."""
        pass

    def reset(self, predictables: List[Any]):
        """Called from execute,  not implemented, override to implement.

        Args:
            predictables: List[Any] - List of predictable objects.
        """
        pass

    def pre_run(self, predictables: List[Any]):
        """Called from execute,  not implemented, override to implement.

        Args:
            predictables: List[Any] - List of predictable objects.
        """
        pass

    def run(self, predictables: List[Any]):
        """Called from execute,  not implemented, override to implement.

        Args:
            predictables: List[Any] - List of predictable objects.
        """
        pass

    def post_run(self, predictables: List[Any]):
        """Called from execute,  not implemented, override to implement.

        Args:
            predictables: List[Any] - List of predictable objects.
        """
        pass

    def evaluate(self, predictables: List[Any]):
        """Called from execute,  not implemented, override to implement.

        Args:
            predictables: List[Any] - List of predictable objects.
        """
        pass



import atexit
import os
from glob import glob
from setuptools import find_packages, setup
from setuptools.command.bdist_egg import bdist_egg
from setuptools.command.install import install

# os.chdir(parent_path)
# parent_path = os.path.abspath(os.path.join(os.path.dirname(__file__),".."))
# curr_dir = os.getcwd()
# print(curr_dir)
main_project_path = os.getcwd()
with open(main_project_path + '/requirements_docker.txt') as f:
	required = f.read().splitlines()
# print('required', required)


def package_files(directory):
	paths = []
	for (path, directories, filenames) in os.walk(directory):
		for filename in filenames:
			paths.append(os.path.join('../' + path, filename))
	return paths


def read(fname):
	return open(os.path.join(os.path.dirname(__file__), fname)).read()


# batch_files = package_files('./')
# print(batch_files)
# print(find_packages())
project_name = '{name-your-service}'


class PostInstallCommand(install):
	"""Post-installation for installation mode."""
	def run(self):
		def _post_install():
			ext = '.whl'
			target_ext = '.zip'
			path = main_project_path + '/dist/'
			target_file_name = path + project_name + target_ext
			if os.path.exists(target_file_name):
				os.remove(target_file_name)
			fileName = os.path.basename(glob(path + "*" + ext)[0])
			target_file_name = path + project_name + target_ext
			os.rename(path + fileName, target_file_name)

		atexit.register(_post_install)
		install.run(self)


class PostInstallCommand2(bdist_egg):
	"""Post-installation for installation mode."""
	def run(self):
		def _post_install():
			ext = '.egg'
			target_ext = '.egg'
			path = main_project_path + '/dist/'
			target_file_name = path + project_name + target_ext
			if os.path.exists(target_file_name):
				os.remove(target_file_name)
			fileName = os.path.basename(glob(path + "*" + ext)[0])
			target_file_name = path + project_name + target_ext
			os.rename(path + fileName, target_file_name)

		atexit.register(_post_install)
		bdist_egg.run(self)


pipeline = package_files('pipeline')
batch_files = package_files('batch_files')
tester = package_files('tester')
config = package_files('config')

setup(
	name=project_name,
	# packages=find_packages(exclude=['server', 'cloud_eval']),
	package_data={
		# If batch_files contains batch_config.json include it:
		# 'batch_files': [
		# 	'batch_config.json',
		# 	# './steps.txt',
		# 	# 'jars/*'
		# ],
		# If example_project contains steps.txt include it:
		'': [
			# '../__init__.py',
			# '../**/*.json',
			# '../**/**/*.json',
			# '../steps.txt',
			# '../test.py'
		] + pipeline + batch_files + tester + config
	},
	# package_data={'': ['batch_config.json', 'cors_allowed_origins.json','.gitignore'] + extra_files + cloud_eval_extra_files + dsp_files},

	# package_data={'': ['config/batch_config.json']},
	include_package_data=True,
	install_requires=required,
	cmdclass={
		'install': PostInstallCommand,
		'bdist_egg': PostInstallCommand2
	}
)
# commands
# for test -  python setup.py pytest
# for build wheel -  python setup.py bdist_wheel
# for source dist -  python setup.py sdist
# for build -  python setup.py build
# for install -  python setup.py install
# for uninstall - python -m pip uninstall trex-batch
# for install - python -m pip install dist/trex-batch-0.1.0-py3-none-any.whl

# deploy to PyPI
# delete dist and build folders
# python setup.py bdist_wheel
# python setup.py sdist
# python setup.py build
# twine upload dist/*
'''
	use
	1. python setup.py install
	2. dsf-cli g model new_model_name
	3. twine check dist/*
	4. twine upload --repository-url https://pypi.org/legacy/ dist/*
	4. twine upload dist/*
	
	pip install dsframework --index-url https://pypi.org/simple

	how to use

	pip install dsframework
	
	dsf-cli generate project my-new-model
'''



##
# @file
# @brief Base class for cloud_eval_client.py
# All of those methods are implemented based on the specific project.
class CloudEvalClientBase:
    """Base class for cloud_eval_client.py, all of those methods needs to be implemented based on
    a specific project. Examples of implementation included in each method.
    """
    UNIMPLEMENTED_ERROR_MESSAGE = "Please override the parent base class methods for using cloud eval"

    def get_request_headers(self, row: dict):
        """! Construct the model service request headers.

            Args:
                row: (dict) - dataset csv record is provided in case it is needed.
            Raises:
                NotImplementedError(CloudEvalClientBase.UNIMPLEMENTED_ERROR_MESSAGE)
        """

        ##
        # Example:
        # ```
        # return {
        #     "accept": "application/json",
        #     "Content-Type": "application/json",
        #     "x-token": "fake-super-secret-token"
        # }
        # ```

        raise NotImplementedError(CloudEvalClientBase.UNIMPLEMENTED_ERROR_MESSAGE)

    def get_request_payload(self, row: dict):
        """! Construct a model service payload from a dataset csv record

            Args:
                row: (dict) - Dataset csv record
            Raises:
                NotImplementedError(CloudEvalClientBase.UNIMPLEMENTED_ERROR_MESSAGE)
        """
        ##
        # Example:
        # ```
        # data = json.loads(record['data'])
        #
        # service_input = PyScoopsClassificationInputs(html_content=data['text'],
        #                                              source=data['source'],
        #                                              queue_name=data['queue_name'],
        #                                              title=data['title']
        #                                              )
        # model_request = service_input  # [input]
        # payload = model_request.dict()
        # return payload
        # ```

        raise NotImplementedError(CloudEvalClientBase.UNIMPLEMENTED_ERROR_MESSAGE)

    def extract_model_predictions_from_response(self, predictions):
        """! Extract the predictions from the service response.

            Args:
                predictions: Prediction result.
            Raises:
                NotImplementedError(CloudEvalClientBase.UNIMPLEMENTED_ERROR_MESSAGE)
        """
        ##
        # Example:
        # ```
        # if type(predictions) == list:
        #     if len(predictions) > 1:
        #         raise Exception("We do not currently support mini batches")
        #     prediction = predictions[0]
        #     try:
        #         prediction_obj = PyScoopsClassificationOutputs(**prediction)
        #         return prediction_obj.dict()
        #     except:
        #         # default answer
        #         return {}
        # ```

        raise NotImplementedError(CloudEvalClientBase.UNIMPLEMENTED_ERROR_MESSAGE)

    def get_endpoint_name(self):
        """! Return model's endpoint name.

            Raises:
                NotImplementedError(CloudEvalClientBase.UNIMPLEMENTED_ERROR_MESSAGE)
        """
        ##
        # For example, if you invoke the model with `/predict` then you can do:
        # ```
        # return "predict"
        # ```

        raise NotImplementedError(CloudEvalClientBase.UNIMPLEMENTED_ERROR_MESSAGE)

    def evaluate_model_results(self, row: dict):
        """! Evaluate results received from the model by comparing them to desired outputs

            Args:
                row: (dict) - Compare prediction results with evaluation.
            Raises:
                NotImplementedError(CloudEvalClientBase.UNIMPLEMENTED_ERROR_MESSAGE)
        """
        ##
        # Example: (From scoops)
        # ```
        # # Load evaluator
        # service_evaluator = PyScoopsClassificationEvaluator()
        #
        # # Extract specific row prediction
        # row_prediction_dict = json.loads(row['prediction'])
        # row_prediction = int(row_prediction_dict['pred'])
        #
        # # Extract target from row information
        # data_dict = json.loads(row['data'])
        # target = int(data_dict['pred'])
        #
        # # Perform evaluation
        # conf_matrix_dict = service_evaluator.get_confusion_matrix(target, row_prediction)
        #
        # return conf_matrix_dict
        # ```

        raise NotImplementedError(CloudEvalClientBase.UNIMPLEMENTED_ERROR_MESSAGE)

    def set_format_output(self, row: dict):
        """! Fit specific information received from the model / evaluation to the desired output format

            Args:
                row: (dict) - Row record, includes prediction and evaluation result
            Raises:
                NotImplementedError(CloudEvalClientBase.UNIMPLEMENTED_ERROR_MESSAGE)
        """
        ##
        # Example (From scoops):
        # ```
        # # Format the dictionary according to the DSP format
        #
        # # Extract data from original dataset row
        # data_dict = json.loads(row['data'])
        #
        # # DSP expects to get the exactly same data that it sent, just with the 'pred' field different
        # basic_dict = {'html_content': data_dict['text'],
        #               'source': data_dict['source'],
        #               'queue_name': data_dict['queue_name'],
        #               'title': data_dict['title'],
        #               'internal_notes': data_dict['internal_notes']}
        #
        # pred_dict = {'pred': int(json.loads(row['prediction'])['pred'])}
        # target_dict = {'pred': int(data_dict['pred'])}
        # pred_dict_to_dsp = dict(basic_dict, **pred_dict)
        # target_dict_to_dsp = dict(basic_dict, **target_dict)
        #
        # row['target'] = json.dumps(target_dict_to_dsp)
        # row['pred'] = json.dumps(pred_dict_to_dsp)
        # row['prob'] = json.loads(row['prediction'])['prob']
        #
        # confusion_matrix_flattened = flatten(row['evaluation'])
        # row.update(confusion_matrix_flattened)
        #
        # # Remove unnecessary fields
        # remove_key = row.pop('evaluation', None)
        # remove_key = row.pop('prediction', None)
        # remove_key = row.pop('data', None)
        # ```

        raise NotImplementedError(CloudEvalClientBase.UNIMPLEMENTED_ERROR_MESSAGE)



"""! @brief Skeleton for implementing a specific stage to be used in a DataProc Workflow template."""
import sys
from typing import Any
from json import loads as json_loads

from dsframework.base.batch.stage_base import ZIDS_Stage


##
# @file
# @brief Stage main class, implements ZIDS_Stage base class.
class generatedStageName(ZIDS_Stage):
    """! Stage class

    Implement a stage that will later be converted to an executable job in a specific workflow.
    """

    def __init__(self, stage_config):
        """! The Stage class (generatedStageName) initializer.
        Base class will load basic configuration parameters, additional fields should be added here

            Args:
                stage_config : Configuration dictionary, loaded from configuration file.
        """

        ##
        # @hidecallgraph @hidecallergraph
        super().__init__(stage_config)

    def get_stage_name(self):
        """! Get the stage name

            Returns:
                A string, containing the stage's name
        """
        return self.__class__.__name__

    def main(self, **kwargs: Any):
        """! Executes the main functionality of the stage.

            Args:
                **kwargs : Whatever is needed for the stage to run properly.
            Returns:

        """
        raise NotImplementedError


if __name__ == "__main__":
    """! Executes the stage by instantiating it and calling the main function.
    Set up argument condition according to the usage of the written stage
    
        Args:
            System argument 1 - Configuration file
            System argument 2 - Start date, received from Airflow
    """
    if sys.argv and len(sys.argv) > 1:
        config = json_loads(sys.argv[1])
        stage = generatedStageName(config)
        if len(sys.argv) > 2:
            start_date = sys.argv[2]
            stage.update_start_date(start_date)
        stage.main()
    else:
        print(f"Stage configuration not provided, Can't run stage")





import requests
import json
from http import HTTPStatus
from pipeline.schema.inputs import generatedProjectNameInputs
from token_generator import tokenGenerator
t = tokenGenerator()
jwtToken = t.generateToken('STG_Conf')
global_headers = {
    'x-token': 'fake-super-secret-token',
    'Authorization': 'Bearer ' + jwtToken
}
base_url = 'http://localhost:8080/'


def post(endPoint, data):
    headers = {"Content-Type": "application/json; charset=UTF-8", **global_headers}
    url = base_url + endPoint
    response = requests.post(url, json=data, headers=headers)
    if response.status_code == HTTPStatus.INTERNAL_SERVER_ERROR:
        data = HTTPStatus.INTERNAL_SERVER_ERROR.description
    else:
        try:
            data = json.loads(response.content)
        except Exception as ex:
            data = response.content
    return data


def get(endPoint, data):
    headers = {"Content-Type": "application/json; charset=UTF-8", **global_headers}
    url = base_url + endPoint
    response = requests.get(url, params=data, headers=headers)
    if response.status_code == HTTPStatus.INTERNAL_SERVER_ERROR:
        data = HTTPStatus.INTERNAL_SERVER_ERROR.description
    else:
        try:
            data = json.loads(response.content)
        except Exception as ex:
            data = response.content
    return data


if __name__ == '__main__':
    # test - parse
    data = {}
    d = generatedProjectNameInputs(**data)

    results = get('livenessprobe', {})
    print('results', results)

    results = post('parse', data)
    print('results', results)

    results = post('predict', data)
    print('results', results)

    # test - test
    batch = []
    batch.append(d.dict())
    results = post('test', batch)
    print('results', results)



# !/usr/bin/env python
# coding: utf-8

from dsframework.base.pipeline.predictables.predictable import ZIDS_Predictable

##
# @file
# @brief Predictable class, implements ZIDS_Predictable base class.
class generatedClass(ZIDS_Predictable):
    """! generatedClass class inherits from ZIDS_Predictable.

    Predictable objects are basically a list of objects which is transferred between different components
    of the pipline.
    Add members to the object here or use the default one's in ZIDS_Predictable baseclass.

    The following example shows how Predictable objects transferred from component to components in the pipeline.
    @code{.py}
    self.predictables = self.preprocess(**kwargs)
    for c in self.components:
        self.predictables = c.execute(self.predictables)
    return self.postprocess(self.predictables)
    @endcode
    """

    def __init__(self) -> None:
        """! Initializer for generatedClass"""
        ##
        # @hidecallgraph @hidecallergraph
        super().__init__()




"""! @brief Get Data stage, for obtaining data from a generic source, such as a database."""
import sys
from typing import Any
from json import loads as json_loads

from dsframework.base.batch.stage_base import ZIDS_Stage


##
# @file
# @brief Stage main class, implements ZIDS_Stage base class.
class GetDataStage(ZIDS_Stage):
    """! Stage class

    Implement a stage that will later be converted to an executable job in a specific workflow.
    """

    def __init__(self, stage_config):
        """! The Stage class (generatedStageName) initializer.
        Base class will load basic configuration parameters, additional fields should be added here

            Args:
                stage_config : Configuration dictionary, loaded from configuration file.
        """

        ##
        # @hidecallgraph @hidecallergraph
        print(f"Initializing Stage: {self.get_name()}")
        super().__init__(stage_config)

    def get_name(self):
        """! Get the stage name
        """
        return self.__class__.__name__

    def main(self, **kwargs: Any):
        """! Executes the main functionality of the stage.

            Args:
                **kwargs : Whatever is needed for the stage to run properly.
        """
        spark_session = self.load_spark()
        df = spark_session.read.options(header='true', inferSchema='true').csv(f"gs://{self.bucket_name}/retail_day.csv")

        df.printSchema()
        df.createOrReplaceTempView("sales")
        highest_price_unit_df = spark_session.sql("select * from sales where UnitPrice >= 3.0")
        # highestPriceUnitDF.write.parquet("gs://us-east1-test-4ba22677-bucket/data/highest_prices.parquet")
        highest_price_unit_df.write.mode("overwrite").parquet(f"{self.bucket_path}/data/highest_prices.parquet")


if __name__ == "__main__":
    """! Executes the stage by instantiating it and calling the main function.
    Set up argument condition according to the usage of the written stage

        Args:
            System argument 1 - Configuration file
            System argument 2 - Start date
    """
    if sys.argv and len(sys.argv) > 1:
        config = json_loads(sys.argv[1])
        stage = GetDataStage(config)
        if len(sys.argv) > 2:
            start_date = sys.argv[2]
            stage.update_start_date(start_date)
        stage.main()
    else:
        print(f"Stage configuration not provided, Can't run stage")


